Function Usefulness
===================


================================================================ ================
 Function name                                                   Usefulness
================================================================ ================
:func:`kwimage.Boxes`                                                         498
:func:`kwimage.Affine`                                                        351
:func:`kwimage.Polygon`                                                       291
:func:`kwimage.imread`                                                        242
:func:`kwimage.imwrite`                                                       240
:func:`kwimage.Detections`                                                    208
:func:`kwimage.Color`                                                         164
:func:`kwimage.grab_test_image`                                               157
:func:`kwimage.imresize`                                                      141
:func:`kwimage.stack_images`                                                  118
:func:`kwimage.draw_text_on_image`                                            105
:func:`kwimage.MultiPolygon`                                                   96
:func:`kwimage.normalize_intensity`                                            96
:func:`kwimage.ensure_uint255`                                                 94
:func:`kwimage.Mask`                                                           91
:func:`kwimage.ensure_float01`                                                 89
:func:`kwimage.ensure_alpha_channel`                                           74
:func:`kwimage.Points`                                                         69
:func:`kwimage.grab_test_image_fpath`                                          68
:func:`kwimage.normalize`                                                      67
:func:`kwimage.convert_colorspace`                                             66
:func:`kwimage.Heatmap`                                                        65
:func:`kwimage.draw_header_text`                                               58
:func:`kwimage.atleast_3channels`                                              53
:func:`kwimage.stack_images_grid`                                              53
:func:`kwimage.overlay_alpha_layers`                                           49
:func:`kwimage.Coords`                                                         46
:func:`kwimage.Projective`                                                     36
:func:`kwimage.gaussian_patch`                                                 34
:func:`kwimage.warp_affine`                                                    33
:func:`kwimage.overlay_alpha_images`                                           29
:func:`kwimage.load_image_shape`                                               28
:func:`kwimage.make_heatmask`                                                  27
:func:`kwimage.gaussian_blur`                                                  22
:func:`kwimage.PolygonList`                                                    22
:func:`kwimage.Segmentation`                                                   19
:func:`kwimage.fill_nans_with_checkers`                                        19
:func:`kwimage.MaskList`                                                       14
:func:`kwimage.warp_projective`                                                14
:func:`kwimage.PointsList`                                                     14
:func:`kwimage.warp_tensor`                                                    12
:func:`kwimage.num_channels`                                                   12
:func:`kwimage.warp_points`                                                    11
:func:`kwimage.SegmentationList`                                               11
:func:`kwimage.morphology`                                                     10
:func:`kwimage.imscale`                                                         9
:func:`kwimage.encode_run_length`                                               9
:func:`kwimage.draw_clf_on_image`                                               8
:func:`kwimage.non_max_supression`                                              6
:func:`kwimage.checkerboard`                                                    6
:func:`kwimage.subpixel_accum`                                                  5
:func:`kwimage.fourier_mask`                                                    5
:func:`kwimage.nodata_checkerboard`                                             5
:func:`kwimage.draw_vector_field`                                               5
:func:`kwimage.imcrop`                                                          5
:func:`kwimage.add_homog`                                                       5
:func:`kwimage.subpixel_getvalue`                                               4
:func:`kwimage.decode_run_length`                                               4
:func:`kwimage.warp_image`                                                      4
:func:`kwimage.draw_line_segments_on_image`                                     4
:func:`kwimage.subpixel_slice`                                                  4
:func:`kwimage.rle_translate`                                                   3
:func:`kwimage.make_vector_field`                                               3
:func:`kwimage.daq_spatial_nms`                                                 3
:func:`kwimage.make_channels_comparable`                                        3
:func:`kwimage.Matrix`                                                          3
:func:`kwimage.Transform`                                                       2
:func:`kwimage.subpixel_setvalue`                                               2
:func:`kwimage.padded_slice`                                                    1
:func:`kwimage.remove_homog`                                                    1
:func:`kwimage.subpixel_translate`                                              1
:func:`kwimage.Linear`                                                          1
:func:`kwimage.subpixel_maximum`                                                1
================================================================ ================

